==> touch_designer_yolo_detection-0.0.2-cp39-cp39-win_amd64.whl: yolo_models/processing/base_processing.py <==
from multiprocessing import shared_memory
import logging

import numpy as np

from .info import ParamsIndex, BufferStates, States

class BaseProcessServer:
    def __init__(self,
                 update_shared_mem_name: str,
                 params_shared_mem_name: str,
                 array_shared_mem_name: str,
                 image_with: int,
                 image_height: int,
                 num_channels: int,
                 image_dtype):
        self._logging  = logging.getLogger("server_processing")
        dtype_size = np.dtype(image_dtype).itemsize
        self._image_size_bytes = image_height * image_with * num_channels * dtype_size
        self._image_width = image_with
        self._image_height = image_height
        self._num_channels = num_channels
        self._image_dtype = image_dtype
        self._sh_mem_update = None
        self._sh_mem_params = None
        self._sh_mem_array = None
        self._shared_array = None
        self._update_shared_mem_name = update_shared_mem_name
        self._params_shared_mem_name = params_shared_mem_name
        self._array_shared_mem_name = array_shared_mem_name

    def init_mem(self):
        assert self._sh_mem_update is None,  "Memory already initialized"
        self._sh_mem_update = shared_memory.SharedMemory(name=self._update_shared_mem_name, create=True, size=len(BufferStates))

        params = [None] * len(ParamsIndex)
        params[ParamsIndex.ETA] = 1.0
        params[ParamsIndex.IOU_THRESH] = 0.5
        params[ParamsIndex.SCORE_THRESH] = 0.5
        params[ParamsIndex.TOP_K] = 0
        params[ParamsIndex.IMAGE_WIDTH] = self._image_width
        params[ParamsIndex.IMAGE_HEIGHT] = self._image_height
        params[ParamsIndex.IMAGE_CHANNELS] = self._num_channels
        params[ParamsIndex.SHARED_ARRAY_MEM_NAME] = self._array_shared_mem_name
        params[ParamsIndex.SHARD_STATE_MEM_NAME] = self._update_shared_mem_name
        params[ParamsIndex.IMAGE_DTYPE] = self._image_dtype

        self._sh_mem_params = shared_memory.ShareableList(
            name=self._params_shared_mem_name, sequence=params
        )
        self._sh_mem_array = shared_memory.SharedMemory(name=self._array_shared_mem_name, create=True, size=self._image_size_bytes)
        self._shared_array = np.ndarray(
            (self._image_height, self._image_width, self._num_channels),
            dtype=self._image_dtype, buffer=self._sh_mem_array.buf)

    def __enter__(self):
        self.init_mem()

        return self

    def __exit__(self, type, value, traceback):
        self._logging.info("Stop processing")
        self.dispose()

    def dispose(self):
        if self._sh_mem_update is not None:
            self._logging.info("Free update shared memory")
            self._sh_mem_update.buf[BufferStates.SERVER_ALIVE] = States.NULL_STATE.value[0]
            self._sh_mem_update.close()
            self._sh_mem_update.unlink()

        del self._shared_array

        if self._sh_mem_array is not None:
            self._logging.info("Free array shared memory")
            self._sh_mem_array.close()
            self._sh_mem_array.unlink()

        if self._sh_mem_params is not None:
            self._logging.info("Free params shared memory")
            self._sh_mem_params.shm.close()
            self._sh_mem_params.shm.unlink()

    def start_processing(self):
        self._sh_mem_update.buf[BufferStates.SERVER] = States.NULL_STATE.value[0]
        self._sh_mem_update.buf[BufferStates.CLIENT] = States.NULL_STATE.value[0]
        self._sh_mem_update.buf[BufferStates.SERVER_ALIVE] = States.IS_SERVER_ALIVE.value[0]

        self._logging.info("Awaiting message")

        while True:
            while self._sh_mem_update.buf[BufferStates.SERVER] != States.READY_SERVER_MESSAGE.value[0]:
                time.sleep(1e-3)

            self._sh_mem_update.buf[BufferStates.SERVER] = States.NULL_STATE.value[0]

            self.process(self._shared_array, self._sh_mem_params)
            self._sh_mem_update.buf[BufferStates.CLIENT] = States.READY_CLIENT_MESSAGE.value[0]

    def process(self, image: np.ndarray, params: list):
        pass

==> touch_designer_yolo_detection-0.1.0-cp39-cp39-win_amd64.whl: yolo_models/processing/base_processing.py <==
from multiprocessing import shared_memory
import logging
import time

import numpy as np

from .info import ParamsIndex, BufferStates, States, DrawInfo


class BaseProcessServer:
    def __init__(self,
                 update_shared_mem_name: str,
                 params_shared_mem_name: str,
                 array_shared_mem_name: str,
                 image_with: int,
                 image_height: int,
                 num_channels: int,
                 image_dtype):
        self._logging = logging.getLogger("server_processing")
        dtype_size = np.dtype(image_dtype).itemsize
        self._image_size_bytes = image_height * image_with * num_channels * dtype_size
        self._image_width = image_with
        self._image_height = image_height
        self._num_channels = num_channels
        self._image_dtype = image_dtype
        self._sh_mem_update = None
        self._sh_mem_params = None
        self._sh_mem_array = None
        self._shared_array = None
        self._update_shared_mem_name = update_shared_mem_name
        self._params_shared_mem_name = params_shared_mem_name
        self._array_shared_mem_name = array_shared_mem_name

    def _get_shared_mem_update(self, create: bool):
        return shared_memory.SharedMemory(
            name=self._update_shared_mem_name, create=create, size=len(BufferStates))

    def _get_shared_mem_array(self, create: bool):
        return shared_memory.SharedMemory(
            name=self._array_shared_mem_name, create=create, size=self._image_size_bytes)

    def init_mem(self):
        assert self._sh_mem_update is None,  "Memory already initialized"
        try:
            self._sh_mem_update = self._get_shared_mem_update(True)
        except FileExistsError:
            self._logging.warning("Cannot create new shared memory. Use existed")
            self._sh_mem_update = self._get_shared_mem_update(False)

        params = [None] * len(ParamsIndex)
        params[ParamsIndex.ETA] = 1.0
        params[ParamsIndex.IOU_THRESH] = 0.5
        params[ParamsIndex.SCORE_THRESH] = 0.5
        params[ParamsIndex.TOP_K] = 0
        params[ParamsIndex.IMAGE_WIDTH] = self._image_width
        params[ParamsIndex.IMAGE_HEIGHT] = self._image_height
        params[ParamsIndex.IMAGE_CHANNELS] = self._num_channels
        params[ParamsIndex.SHARED_ARRAY_MEM_NAME] = self._array_shared_mem_name
        params[ParamsIndex.SHARD_STATE_MEM_NAME] = self._update_shared_mem_name
        params[ParamsIndex.IMAGE_DTYPE] = self._image_dtype
        params[ParamsIndex.DRAW_INFO] = int(DrawInfo.DRAW_BBOX)

        self._sh_mem_params = shared_memory.ShareableList(
            name=self._params_shared_mem_name, sequence=params
        )

        try:
            self._sh_mem_array = self._get_shared_mem_array(True)
        except FileExistsError:
            self._sh_mem_array = self._get_shared_mem_array(False)

        self._shared_array = np.ndarray(
            (self._image_height, self._image_width, self._num_channels),
            dtype=self._image_dtype, buffer=self._sh_mem_array.buf)

    def __enter__(self):
        self.init_mem()

        return self

    def __exit__(self, type, value, traceback):
        self._logging.info("Stop processing")
        self.dispose()

    def dispose(self):
        if self._sh_mem_update is not None:
            self._logging.info("Free update shared memory")
            self._sh_mem_update.buf[BufferStates.SERVER_ALIVE] = States.NULL_STATE.value[0]
            self._sh_mem_update.close()
            self._sh_mem_update.unlink()

        del self._shared_array

        if self._sh_mem_array is not None:
            self._logging.info("Free array shared memory")
            self._sh_mem_array.close()
            self._sh_mem_array.unlink()

        if self._sh_mem_params is not None:
            self._logging.info("Free params shared memory")
            self._sh_mem_params.shm.close()
            self._sh_mem_params.shm.unlink()

    def start_processing(self):
        self._sh_mem_update.buf[BufferStates.SERVER] = States.NULL_STATE.value[0]
        self._sh_mem_update.buf[BufferStates.CLIENT] = States.NULL_STATE.value[0]
        self._sh_mem_update.buf[BufferStates.SERVER_ALIVE] = States.IS_SERVER_ALIVE.value[0]

        self._logging.info("Awaiting message")

        while True:
            while self._sh_mem_update.buf[BufferStates.SERVER] != States.READY_SERVER_MESSAGE.value[0]:
                time.sleep(1e-3)

            self._sh_mem_update.buf[BufferStates.SERVER] = States.NULL_STATE.value[0]

            image_height = self._sh_mem_params[ParamsIndex.IMAGE_HEIGHT]
            image_width = self._sh_mem_params[ParamsIndex.IMAGE_WIDTH]

            actual_image = self._shared_array[:image_height, :image_width]

            self.process(actual_image, self._sh_mem_params)
            self._shared_array[:image_height, :image_width] = actual_image

            self._sh_mem_update.buf[BufferStates.CLIENT] = States.READY_CLIENT_MESSAGE.value[0]

    def process(self, image: np.ndarray, params: list):
        pass
